@@ -1,20 +1,21 @@
 import json
 import logging
+from collections import namedtuple
 from dataclasses import dataclass
 from typing import Any, Dict, Optional
 
+from pythonit_toolkit.headers import PASTAPORTO_X_HEADER, SERVICE_JWT_HEADER
 from pythonit_toolkit.pastaporto.test import (
     fake_pastaporto_token_for_user,
     fake_service_to_service_token,
 )
-from ward import fixture
-
-from pythonit_toolkit.headers import SERVICE_JWT_HEADER, PASTAPORTO_X_HEADER
-from .test_client import testclient
 
 logger = logging.getLogger(__name__)
 
 
+SimulatedUser = namedtuple("User", ["id", "email", "is_staff"])
+
+
 @dataclass
 class Response:
     errors: Optional[Dict[str, Any]]
@@ -23,7 +24,8 @@ class Response:
 
 class GraphQLClient:
     def __init__(
-        self, client,
+        self,
+        client,
         *,
         pastaporto_secret: Optional[str] = None,
         service_to_service_secret: Optional[str] = None,
@@ -65,7 +67,7 @@ class GraphQLClient:
         data = json.loads(resp.content.decode())
         return Response(errors=data.get("errors"), data=data.get("data"))
 
-    def force_login(self, user):
+    def force_login(self, user: SimulatedUser):
         self.pastaporto_token = fake_pastaporto_token_for_user(
             {"id": user.id, "email": user.email},
             str(self._pastaporto_secret),
@@ -74,5 +76,7 @@ class GraphQLClient:
 
     def force_service_login(self, key: Optional[str] = None):
         self.service_to_service_token = fake_service_to_service_token(
-            str(key or self._service_to_service_secret), issuer="gateway", audience="users-service"
+            str(key or self._service_to_service_secret),
+            issuer="gateway",
+            audience="users-service",
         )
